;; Generated package description from posframe.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "posframe" "1.5.1.0.20260423.21349" "Pop a posframe (just a frame) at point" '((emacs "26.1")) :commit "fcf1757baee481f617fbf2dc39f8c561207df263" :authors '(("Feng Shu" . "tumashu@163.com")) :maintainer '("Feng Shu" . "tumashu@163.com") :keywords '("convenience" "tooltip") :url "https://github.com/tumashu/posframe")
